==> JOB-3.1.2.tar.gz: JOB-3.1.2/ob/src/com/ooc/CORBA/LocalObject.java <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

package com.ooc.CORBA;

// This class must be public
abstract public class LocalObject implements org.omg.CORBA.Object
{
    final public org.omg.CORBA.portable.Delegate
    _get_delegate()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public void
    _set_delegate(org.omg.CORBA.portable.Delegate del)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    public String[]
    _ids()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.ImplementationDef
    _get_implementation()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.InterfaceDef
    _get_interface()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Object
    _duplicate()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public void
    _release()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public boolean
    _is_a(String repository_id)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public boolean
    _is_equivalent(org.omg.CORBA.Object rhs)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public boolean
    _non_existent()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public int
    _hash(int maximum)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Request
    _request(String operation)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Request
    _create_request(org.omg.CORBA.Context ctx, String operation,
		    org.omg.CORBA.NVList arg_list,
		    org.omg.CORBA.NamedValue result)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Request
    _create_request(org.omg.CORBA.Context ctx, String operation,
		    org.omg.CORBA.NVList arg_list,
		    org.omg.CORBA.NamedValue result,
		    org.omg.CORBA.ExceptionList excepts,
		    org.omg.CORBA.ContextList contexts)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Policy
    _get_policy(int policy_type)
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Policy
    _get_effective_policy_override(int policy_type)
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Object
    _set_policy_overrides(org.omg.CORBA.Policy[] np,
			  org.omg.CORBA.SetOverrideType set_add)
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Policy[]
    _get_policy_overrides(int[] types)
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public boolean
    _validate_policies(org.omg.CORBA.Policy[] inconsistent_policies)
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.DomainManager[]
    _get_domain_managers()
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }


    // For compatibility with Sun's JDK 1.2RC2 ORB

    final public org.omg.CORBA.Object
    _set_policy_override(org.omg.CORBA.Policy[] np,
			 org.omg.CORBA.SetOverrideType set_add)
    {
        throw new org.omg.CORBA.NO_IMPLEMENT();
    }

    final public org.omg.CORBA.Object
    _get_interface_def()
    {
        throw new org.omg.CORBA.NO_IMPLEMENT();
    }
}

==> JOB-3.3.2.tar.gz: JOB-3.3.2/ob/src/com/ooc/CORBA/LocalObject.java <==
// **********************************************************************
//
// Copyright (c) 2000
// Object Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

package com.ooc.CORBA;

// This class must be public
abstract public class LocalObject implements org.omg.CORBA.Object
{
    final public org.omg.CORBA.portable.Delegate
    _get_delegate()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public void
    _set_delegate(org.omg.CORBA.portable.Delegate del)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    public String[]
    _ids()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.ImplementationDef
    _get_implementation()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.InterfaceDef
    _get_interface()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Object
    _duplicate()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public void
    _release()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public boolean
    _is_a(String repository_id)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public boolean
    _is_equivalent(org.omg.CORBA.Object rhs)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public boolean
    _non_existent()
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public int
    _hash(int maximum)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Request
    _request(String operation)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Request
    _create_request(org.omg.CORBA.Context ctx, String operation,
		    org.omg.CORBA.NVList arg_list,
		    org.omg.CORBA.NamedValue result)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Request
    _create_request(org.omg.CORBA.Context ctx, String operation,
		    org.omg.CORBA.NVList arg_list,
		    org.omg.CORBA.NamedValue result,
		    org.omg.CORBA.ExceptionList excepts,
		    org.omg.CORBA.ContextList contexts)
    {
	throw new org.omg.CORBA.BAD_OPERATION();
    }

    //
    // For compatibility with JDK 1.2
    //

    final public org.omg.CORBA.Object
    _get_interface_def()
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Policy
    _get_policy(int policy_type)
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Object
    _set_policy_override(org.omg.CORBA.Policy[] np,
			 org.omg.CORBA.SetOverrideType set_add)
    {
        throw new org.omg.CORBA.NO_IMPLEMENT();
    }

    final public org.omg.CORBA.DomainManager[]
    _get_domain_managers()
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    //
    // ORBacus specific
    //

    final public org.omg.CORBA.Object
    _set_policy_overrides(org.omg.CORBA.Policy[] np,
			  org.omg.CORBA.SetOverrideType set_add)
        throws org.omg.CORBA.PolicyManagerPackage.InvalidPolicies
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Policy
    _get_effective_policy_override(int policy_type)
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public org.omg.CORBA.Policy[]
    _get_policy_overrides(int[] types)
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }

    final public boolean
    _validate_policies(org.omg.CORBA.Policy[] inconsistent_policies)
    {
        throw new org.omg.CORBA.BAD_OPERATION();
    }
}
